Learn by Examples
=================

.. toctree::
    notebooks/01Load_xml_measurement_files.ipynb.rst
    notebooks/02Define_sections.ipynb.rst
    notebooks/03Calculate_variance_Stokes.ipynb.rst
    notebooks/04Calibrate_single_ols.ipynb.rst
    notebooks/05Calibrate_single_wls.ipynb.rst
    notebooks/06Calibrate_double_ols.ipynb.rst
    notebooks/07Calibrate_double_wls.ipynb.rst
